import { Injectable, Component, EventEmitter, Input, Output, ViewChild, NgModule } from '@angular/core';
import * as Plotlyjs from 'plotly.js';
import { CommonModule } from '@angular/common';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class PlotlyService {
    constructor() {
        this.plotly = Plotlyjs;
        if (typeof this.plotly === 'undefined') {
            throw new Error(`Peer dependency plotly.js isn't installed`);
        }
    }
    /**
     * @param {?} div
     * @param {?} data
     * @param {?=} layout
     * @param {?=} config
     * @return {?}
     */
    newPlot(div, data, layout, config) {
        return this.plotly.newPlot(div, data, layout);
    }
    /**
     * @param {?} div
     * @param {?} data
     * @param {?=} layout
     * @param {?=} config
     * @return {?}
     */
    plot(div, data, layout, config) {
        return this.plotly.plot(div, data, layout);
    }
    /**
     * @param {?} div
     * @return {?}
     */
    resize(div) {
        return this.plotly.Plots.resize(div);
    }
}
PlotlyService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
PlotlyService.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
const ɵ0 = () => window;
class PlotComponent {
    /**
     * @param {?} plotly
     * @param {?} window
     */
    constructor(plotly, window) {
        this.plotly = plotly;
        this.window = window;
        this.revision = 0;
        this.className = '';
        this.debug = false;
        this.useResizeHandler = false;
        this.initialized = new EventEmitter();
        this.update = new EventEmitter();
        this.purge = new EventEmitter();
        this.error = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.plotly.newPlot(this.plotEl.nativeElement, this.data, this.layout, this.config).then(plotlyInstance => {
            this.plotlyInstance = plotlyInstance;
            (/** @type {?} */ (this.window)).gd = this.debug ? plotlyInstance : undefined;
            const /** @type {?} */ figure = this.createFigure();
            this.initialized.emit(figure);
        }, err => {
            console.error('Error while plotting:', err);
            this.error.emit(err);
        });
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        if (typeof this.resizeHandler === 'function') {
            this.window.removeEventListener('resize', /** @type {?} */ (this.resizeHandler));
            this.resizeHandler = undefined;
        }
        const /** @type {?} */ figure = this.createFigure();
        this.purge.emit(figure);
    }
    /**
     * @return {?}
     */
    createFigure() {
        const /** @type {?} */ p = this.plotlyInstance;
        const /** @type {?} */ figure = {
            data: p.data,
            layout: p.layout,
            frames: p._transitionData ? p._transitionData._frames : null
        };
        return figure;
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        let /** @type {?} */ shouldUpdate = false;
        const /** @type {?} */ revision = changes["revision"];
        if (revision && !revision.isFirstChange()) {
            shouldUpdate = true;
        }
        const /** @type {?} */ data = changes["data"];
        if (data && !data.isFirstChange()) {
            shouldUpdate = true;
        }
        const /** @type {?} */ debug = changes["debug"];
        if (debug && !debug.isFirstChange()) {
            shouldUpdate = true;
        }
        if (shouldUpdate) {
            this.redraw();
        }
        this.updateWindowResizeHandler();
    }
    /**
     * @return {?}
     */
    redraw() {
        if (!this.plotlyInstance) {
            const /** @type {?} */ error = new Error(`Plotly component wasn't initialized`);
            this.error.emit(error);
            throw error;
        }
        this.plotly.plot(this.plotlyInstance, this.data, this.layout, this.config).then(plotlyInstance => {
            this.update.emit(this.createFigure());
            (/** @type {?} */ (this.window)).gd = this.debug ? plotlyInstance : undefined;
        });
    }
    /**
     * @return {?}
     */
    updateWindowResizeHandler() {
        if (this.useResizeHandler) {
            if (!this.resizeHandler) {
                this.resizeHandler = () => this.plotly.resize(this.plotlyInstance);
                this.window.addEventListener('resize', /** @type {?} */ (this.resizeHandler));
            }
        }
        else {
            if (typeof this.resizeHandler === 'function') {
                this.window.removeEventListener('resize', /** @type {?} */ (this.resizeHandler));
                this.resizeHandler = undefined;
            }
        }
    }
}
PlotComponent.decorators = [
    { type: Component, args: [{
                selector: 'plotly-plot',
                template: `<div #plot [attr.id]="divId" [className]="className" [ngStyle]="style"></div>`,
                providers: [PlotlyService, { provide: Window, useFactory: ɵ0 }],
            },] },
];
/** @nocollapse */
PlotComponent.ctorParameters = () => [
    { type: PlotlyService, },
    { type: Window, },
];
PlotComponent.propDecorators = {
    "plotEl": [{ type: ViewChild, args: ['plot',] },],
    "data": [{ type: Input },],
    "layout": [{ type: Input },],
    "config": [{ type: Input },],
    "style": [{ type: Input },],
    "divId": [{ type: Input },],
    "revision": [{ type: Input },],
    "className": [{ type: Input },],
    "debug": [{ type: Input },],
    "useResizeHandler": [{ type: Input },],
    "initialized": [{ type: Output },],
    "update": [{ type: Output },],
    "purge": [{ type: Output },],
    "error": [{ type: Output },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class PlotlyModule {
}
PlotlyModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule],
                declarations: [PlotComponent],
                exports: [PlotComponent],
            },] },
];
/** @nocollapse */
PlotlyModule.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Generated bundle index. Do not edit.
 */

export { PlotlyModule, PlotComponent, PlotlyService };
//# sourceMappingURL=angular-plotly.js.js.map
